rmsFit — biskit 3.0.0a1 documentation

# rmsFit

superimpose 2 structures iteratively

Functions Overview

`findTransformation` | Match two arrays by rotation and translation.
`match` | Matches two arrays onto each other, while iteratively removing outliers.
`rowDistances` | Calculate the distances between the items of two arrays (of same shape) after least-squares superpositioning.
`svd` | Singular Value Decomposition.

Classes Overview

## rmsFit Module Details

`biskit.rmsFit.` `findTransformation`(x, y)

  Match two arrays by rotation and translation. Returns the rotation matrix and the translation vector.

  Parameters: | x (array('f')) – first set of coordinates y (array('f')) – second set of coordinates
  Returns: | rotation matrix (3x3) and translation vector (1x3)
  Return type: | array, array

`biskit.rmsFit.` `match`(x, y, n_iterations=1, z=2, eps_rmsd=0.5, eps_stdv=0.05)

  Matches two arrays onto each other, while iteratively removing outliers. Superimposed array y would be C{ N0.dot(y, N0.transpose(r)) + t }.

  Parameters: | n_iterations (1|0) – number of calculations:: 1 .. no iteration 0 .. until convergence z (float) – number of standard deviations for outlier definition (default: 2) eps_rmsd (float) – tolerance in rmsd (default: 0.5) eps_stdv (float) – tolerance in standard deviations (default: 0.05)
  Returns: | (r,t), [ [percent_considered, rmsd_for_it, outliers] ]
  Return type: | (array, array), [float, float, int]

`biskit.rmsFit.` `rowDistances`(x, y)

  Calculate the distances between the items of two arrays (of same shape) after least-squares superpositioning.

  Parameters: | x (array('f')) – first set of coordinates y (array('f')) – second set of coordinates
  Returns: | array( len(x), ‘f’ ), distance between x[i] and y[i] for all i
  Return type: | array